import React, {FC} from "react";
import ExternalTrack from "../model/externalTrack.model";
import Icon from "./Icon";

const ExternalTrackCard: FC<ExternalTrackCardProps> = ({
                                                           track,
                                                           source,
                                                           imported,
                                                           previewing,
                                                           onImportClick,
                                                           onPreviewClick,
                                                           onSpotifyIconClick
                                                       }) => (
    <div className="external-track-card">
        <img className="external-track-thumbnail" src={track.thumbnailUrl} alt={'Thumbnail - ' + track.name}/>
        <div className="external-track-description">
            <p className="external-track-title" onClick={onSpotifyIconClick}
               title={'Open on ' + source}>{track.name}</p>
            <p className="external-track-subtitle">{track.authors.join(', ') + ' - ' + track.albumName}</p>
        </div>
        <div className="external-track-actions">
            {previewing ?
                <Icon name="pause" hover="pause-fill" onClick={onPreviewClick} title="Stop preview"/> :
                <Icon name="play" hover="play-fill" onClick={onPreviewClick} title="Preview track"/>}

            {imported ?
                <Icon name="check" hover="check-circle-fill" onClick={onImportClick} title="Remove from library"/> :
                <Icon name="plus" hover="plus-circle-fill" onClick={onImportClick} title="Import in library"/>}
        </div>
    </div>
);

interface ExternalTrackCardProps {
    track: ExternalTrack,
    source: string,
    imported: boolean,
    previewing: boolean,
    onImportClick: () => void,
    onPreviewClick: () => void,
    onSpotifyIconClick: () => void
}

export default ExternalTrackCard;