import React, {useEffect, useState} from "react";
import SearchSongForm from "../components/SearchSongForm";
import api from "../api";
import SearchResultContainer from "./SearchResult.container";
import ExternalTrack from "../model/externalTrack.model";

const audio = new Audio();

const SearchContainer: React.FC = () => {
    const [results, setResults] = useState({});
    const [previewTrackId, setPreviewTrackId] = useState("");
    const [importedTracksIds, setImportedTracksIds] = useState(new Array<string>());

    const submitSearchHandler = async (query: string) => {
        const response = await api.get("/tracks/search?q=" + query, {withCredentials: true});
        setResults(response.data);
    };

    const onPreviewClick = (trackId: string, previewUrl: string) => {
        audio.pause();

        if (trackId !== previewTrackId) {
            audio.src = previewUrl;
            audio.play();
            setPreviewTrackId(trackId);
        } else {
            setPreviewTrackId("");
        }
    };

    const onImportClick = async (trackId: string) => {
        if (importedTracksIds.some(id => trackId === id)) {
            await api.delete(`/tracks/trackId/spotify/${trackId}`);
            setImportedTracksIds(importedTracksIds.filter(id => trackId !== id));
        } else {
            await api.post("/tracks/", {source: "spotify", trackId}, {withCredentials: true});
            setImportedTracksIds([...importedTracksIds, trackId]);
        }
    };

    const onSpotifyIconClick = (trackId: string) => {
        const spotifyTrackUrl = "https://open.spotify.com/track/" + trackId;
        window.open(spotifyTrackUrl, "_blank");
    };

    useEffect(() => {
        const getLibraryTrackIds = async () => {
            const response = await api.get("/tracks/trackIds/");
            if (response.data.spotify) {
                setImportedTracksIds(response.data.spotify);
            }
        };

        getLibraryTrackIds();
    }, []);

    return (
        <>
            <SearchSongForm submitSearchHandler={submitSearchHandler}/>
            {Object.entries(results).map(([source, tracks]) => (
                <SearchResultContainer key={source} source={source} importedTracksIds={importedTracksIds}
                                       previewTrackId={previewTrackId}
                                       tracks={tracks as ExternalTrack[]}
                                       onImportClick={onImportClick}
                                       onPreviewClick={onPreviewClick}
                                       onSpotifyIconClick={onSpotifyIconClick}/>
            ))}
        </>
    )
}

export default SearchContainer;