import {FC} from "react";
import ExternalTrackCard from "../components/ExternalTrackCard";
import ExternalTrack from "../model/externalTrack.model";
import SpotifyLogo from "../images/Spotify_Logo_RGB_White.png";
import "../style/search-results.scss";

const SearchResultContainer: FC<SearchResultContainerProps> = ({
                                                                   source,
                                                                   importedTracksIds,
                                                                   previewTrackId,
                                                                   tracks,
                                                                   onImportClick,
                                                                   onPreviewClick,
                                                                   onSpotifyIconClick
                                                               }) => {
    return (
        <div className="d-flex flex-column">
            <img className="search-results-source-logo" src={SpotifyLogo} alt="Spotify logo"/>
            <div className="search-results-wrapper d-flex flex-row">
                {tracks.map(s => (
                    <ExternalTrackCard key={s.trackId} track={s}
                                       source={source}
                                       imported={importedTracksIds.some(id => s.trackId === id)}
                                       previewing={previewTrackId === s.trackId}
                                       onImportClick={() => onImportClick(s.trackId)}
                                       onPreviewClick={() => onPreviewClick(s.trackId, s.previewUrl)}
                                       onSpotifyIconClick={() => onSpotifyIconClick(s.trackId)}/>
                ))}
            </div>
        </div>
    );
};

interface SearchResultContainerProps {
    source: string,
    importedTracksIds: string[],
    previewTrackId: string,
    tracks: ExternalTrack[],
    onImportClick: (trackId: string) => void,
    onPreviewClick: (trackId: string, previewUrl: string) => void,
    onSpotifyIconClick: (trackId: string) => void
}

export default SearchResultContainer;